/**
 *
 */
package edu.agh.sm2006.nmea2kml;

import java.util.Collection;
import java.util.Iterator;

/**
 * @author Kuba Madej
 *
 */
public class ColorPrinter extends Printer {
	private static final int SPEED_MULTIPLIER = 5;

	private double maxSpeed;

	@Override
	public void printLocations(Collection<Location> locations) {
		for (Location location : locations) {
			final int speed = (int) (location.getSpeed() * SPEED_MULTIPLIER);
			maxSpeed = Math.max(maxSpeed, speed);
		}

		Iterator<Location> iterator = locations.iterator();

		Location lastLocation = iterator.next();

		while (iterator.hasNext()) {
			final Location actualLocation = iterator.next();

			System.out
					.println("<Placemark><description></description><name></name><visibility>1</visibility><open>0</open><Style><LineStyle><color>"
							+ String.format("%x", getColor(actualLocation
									.getSpeed()))
							+ "</color><width>2</width></LineStyle><PolyStyle><color>7f00ff00</color></PolyStyle></Style><LineString><extrude>1</extrude><coordinates>");

			printLocation(actualLocation);
			printLocation(lastLocation);

			System.out.println("</coordinates></LineString></Placemark>");

			lastLocation = actualLocation;
		}
	}

	private int getColor(double _speed) {
		final int speed = (int) (_speed * SPEED_MULTIPLIER);
		final int b = 64;
		final int r = (int) (255 * (speed / maxSpeed));
		final int g = (int) (255 * ((maxSpeed - speed) / maxSpeed));

		return 0xff000000 | b << 16 | g << 8 | r;
	}

	private void printLocation(Location location) {
		System.out.printf("%f,%f,1\n", location.getLongtitude(), location
				.getLatitude());
	}

}
